$set 3 #Configmenu

$ #ConfigOptions
# Ayarlar
$ #FocusModel
# Hizalama
$ #WindowPlacement
# Pencere yerleimi
$ #ImageDithering
# Resim oluturulmas
$ #OpaqueMove
# Donuk Pencere Tanmas
$ #FullMax
# Ekran Kapla
$ #FocusNew
# Yeni Pencereleri Hizala
$ #FocusLast
# Masast deiiminde pencereyi hizala
$ #ClickToFocus
# Hizalamak iin tkla
$ #SloppyFocus
# Yava Hizala
$ #AutoRaise
# Otomatik Gster
$ #SmartRows
# Akll Yerleim( Sralar )
$ #SmartCols
# Akll Yerleim( Stunlar )
$ #Cascade
# Kademeli Yerleim
$ #LeftRight
# Soldan saa
$ #RightLeft
# Sadan sola
$ #TopBottom
# stten aaa
$ #BottomTop
# Alttan ste
$ #Tabs
# Sekmeleri Kullan
$ #Icons
# Sekme konlar
$ #TabPlacement
# Sekme Yerleimi
$ #TabRotateVertical
# Sekmeleri Dey Yerletir
$ #SemiSloppyFocus
# Aynlar Hizala
$ #MaxOverSlit
# Kesik zerinden Ekran Kapla
$ #SloppyWindowGrouping
# Penecere Gruplandrmas
$ #WorkspaceWarping
# Masast Sapmas
$ #DesktopWheeling
# Masast Geii
